@@ -724,4 +724,29 @@ char *turn_strdup_func(const char* s, const char* file, int line) {
 #endif
 #endif
 
+////////////////////////////////
+
+int is_secure_username(const u08bits *username)
+{
+	int ret = 0;
+	if(username) {
+		unsigned char *s0 = (unsigned char*)turn_strdup((const char*)username);
+		unsigned char *s = s0;
+		while(*s) {
+			*s = (unsigned char)tolower((int)*s);
+			++s;
+		}
+		s = s0;
+		if(strstr((char*)s," ")||strstr((char*)s,"\t")||strstr((char*)s,"'")||strstr((char*)s,"\"")||strstr((char*)s,"\n")||strstr((char*)s,"\r")||strstr((char*)s,"\\")) {
+			;
+		} else if(strstr((char*)s,"union")&&strstr((char*)s,"select")) {
+			;
+		} else {
+			ret = 1;
+		}
+		turn_free(s,strlen((char*)s));
+	}
+	return ret;
+}
+
 //////////////////////////////////////////////////////////////////
