@@ -325,9 +325,6 @@ static void free_blist_elem(ioa_engine_handle e, stun_buffer_list_elem *buf_elem
 
 /************** ENGINE *************************/
 
-#define TURN_JIFFIE_SIZE (3)
-#define TURN_JIFFIE_LENGTH (1<<(TURN_JIFFIE_SIZE))
-
 static void timer_handler(ioa_engine_handle e, void* arg) {
 
   UNUSED_ARG(arg);
@@ -335,7 +332,7 @@ static void timer_handler(ioa_engine_handle e, void* arg) {
   _log_time_value = turn_time();
   _log_time_value_set = 1;
 
-  e->jiffie = _log_time_value >> TURN_JIFFIE_SIZE;
+  e->jiffie = _log_time_value;
 }
 
 ioa_engine_handle create_ioa_engine(super_memory_t *sm,
@@ -619,46 +616,61 @@ void delete_ioa_timer(ioa_timer_handle th)
 
 /************** SOCKETS HELPERS ***********************/
 
-static int ioa_socket_check_bandwidth(ioa_socket_handle s, size_t sz, int read)
+int ioa_socket_check_bandwidth(ioa_socket_handle s, ioa_network_buffer_handle nbh, int read)
 {
-	if(s && (s->e) && sz && (s->e->max_bpj != 0) && (s->sat == CLIENT_SOCKET) && s->session) {
+	if(s && (s->e) && nbh && (s->e->max_bpj != 0) &&
+			((s->sat == CLIENT_SOCKET) || (s->sat == RELAY_SOCKET) || (s->sat == RELAY_RTCP_SOCKET)) &&
+			s->session) {
+
+		size_t sz = ioa_network_buffer_get_size(nbh);
 
 		band_limit_t max_bps = s->e->max_bpj;
 
-		max_bps = max_bps<<TURN_JIFFIE_SIZE;
+		if(max_bps<1)
+			return 1;
+
+		struct traffic_bytes *traffic = &(s->data_traffic);
+
+		if(s->sat == CLIENT_SOCKET) {
+			u08bits *buf = ioa_network_buffer_data(nbh);
+			if(stun_is_command_message_str(buf,sz)) {
+				u16bits method = stun_get_method_str(buf,sz);
+				if((method != STUN_METHOD_SEND) && (method != STUN_METHOD_DATA)) {
+					traffic = &(s->control_traffic);
+				}
+			}
+		}
 
 		band_limit_t bsz = (band_limit_t)sz;
 
 		if(s->jiffie != s->e->jiffie) {
 
 			s->jiffie = s->e->jiffie;
-			s->jiffie_bytes_read = 0;
-			s->jiffie_bytes_write = 0;
+			traffic->jiffie_bytes_read = 0;
+			traffic->jiffie_bytes_write = 0;
 
 			if(bsz > max_bps) {
-
 				return 0;
-
 			} else {
 				if(read)
-					s->jiffie_bytes_read = bsz;
+					traffic->jiffie_bytes_read = bsz;
 				else
-					s->jiffie_bytes_write = bsz;
+					traffic->jiffie_bytes_write = bsz;
 				return 1;
 			}
 		} else {
 			band_limit_t nsz;
 			if(read)
-				nsz = s->jiffie_bytes_read + bsz;
+				nsz = traffic->jiffie_bytes_read + bsz;
 			else
-				nsz = s->jiffie_bytes_write + bsz;
+				nsz = traffic->jiffie_bytes_write + bsz;
 			if(nsz > max_bps) {
 				return 0;
 			} else {
 				if(read)
-					s->jiffie_bytes_read = nsz;
+					traffic->jiffie_bytes_read = nsz;
 				else
-					s->jiffie_bytes_write = nsz;
+					traffic->jiffie_bytes_write = nsz;
 				return 1;
 			}
 		}
@@ -2390,11 +2402,13 @@ static int socket_input_worker(ioa_socket_handle s)
 	}
 
 	if ((ret!=-1) && (len >= 0)) {
-		if(ioa_socket_check_bandwidth(s,(size_t)len,1)) {
-			if(app_msg_len)
-				buf_elem->buf.len = app_msg_len;
-			else
-				buf_elem->buf.len = len;
+
+		if(app_msg_len)
+			buf_elem->buf.len = app_msg_len;
+		else
+			buf_elem->buf.len = len;
+
+		if(ioa_socket_check_bandwidth(s,buf_elem,1)) {
 
 			if(s->read_cb) {
 				ioa_net_data nd;
@@ -2958,7 +2972,7 @@ int send_data_from_ioa_socket_nbh(ioa_socket_handle s, ioa_addr* dest_addr,
 		TURN_LOG_FUNC(TURN_LOG_LEVEL_INFO, "!!! %s socket: 0x%lx was closed\n", __FUNCTION__,(long)s);
 
 	} else if (nbh) {
-		if(!ioa_socket_check_bandwidth(s,ioa_network_buffer_get_size(nbh),0)) {
+		if(!ioa_socket_check_bandwidth(s,nbh,0)) {
 			/* Bandwidth exhausted, we pretend everything is fine: */
 			ret = (int)(ioa_network_buffer_get_size(nbh));
 		} else {
